@@ -10,5 +10,5 @@ class ConfigNotLoadedError(ConfigError):
     pass
 
 
-class ConfigKeyError(ConfigError):
+class ConfigKeyError(KeyError):
     pass
